@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -70,14 +70,11 @@ public class RSSFolder implements MessagingFolder {
 
     private final List<MessagingPermission> permissions;
 
-    public RSSFolder(int user) {
+    public RSSFolder(final int user) {
         super();
         final MessagingPermission mp = DefaultMessagingPermission.newInstance();
-        mp.setAllPermissions(
-            MessagingPermission.READ_FOLDER,
-            MessagingPermission.READ_ALL_OBJECTS,
-            MessagingPermission.NO_PERMISSIONS,
-            MessagingPermission.DELETE_OWN_OBJECTS);
+        final int[] arr = RSSMessagingService.getStaticRootPerms();
+        mp.setAllPermissions(arr[0], arr[1], arr[2], arr[3]);
         mp.setAdmin(false);
         mp.setEntity(user);
         mp.setGroup(false);
