@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,13 +51,15 @@ package com.openexchange.messaging.rss;
 
 import java.util.Collections;
 import java.util.List;
+import java.util.Set;
 import com.openexchange.datatypes.genericonf.DynamicFormDescription;
 import com.openexchange.datatypes.genericonf.FormElement;
+import com.openexchange.datatypes.genericonf.ReadOnlyDynamicFormDescription;
 import com.openexchange.messaging.MessagingAccountAccess;
 import com.openexchange.messaging.MessagingAccountManager;
 import com.openexchange.messaging.MessagingAccountTransport;
 import com.openexchange.messaging.MessagingAction;
-import com.openexchange.messaging.MessagingException;
+import com.openexchange.messaging.MessagingPermission;
 import com.openexchange.messaging.MessagingService;
 import com.openexchange.messaging.generic.DefaultMessagingAccountManager;
 import com.openexchange.session.Session;
@@ -73,17 +75,20 @@ import com.sun.syndication.fetcher.impl.HttpURLFeedFetcher;
 public class RSSMessagingService implements MessagingService {
 
     private static final String DISPLAY_NAME = "RSS Feed";
-    private static final DynamicFormDescription FORM_DESCRIPTION = new DynamicFormDescription();
+    private static final DynamicFormDescription FORM_DESCRIPTION;
     public static final String ID = "com.openexchange.messaging.rss";
-    static {
-        FORM_DESCRIPTION.add(FormElement.input("url", FormStrings.FORM_LABEL_URL));
-    }
-    
-    private final MessagingAccountManager accountManager = new DefaultMessagingAccountManager(ID);
-    private FeedFetcher fetcher = new HttpURLFeedFetcher(HashMapFeedInfoCache.getInstance());
 
-    
-    public MessagingAccountAccess getAccountAccess(int accountId, Session session) throws MessagingException {
+    static {
+        final DynamicFormDescription fd = new DynamicFormDescription();
+        fd.add(FormElement.input("url", FormStrings.FORM_LABEL_URL));
+        FORM_DESCRIPTION = new ReadOnlyDynamicFormDescription(fd);
+    }
+
+    private final MessagingAccountManager accountManager = new DefaultMessagingAccountManager(this);
+
+    private final FeedFetcher fetcher = new HttpURLFeedFetcher(HashMapFeedInfoCache.getInstance());
+
+    public MessagingAccountAccess getAccountAccess(final int accountId, final Session session) {
         return new RSSFeedOperations(accountId, session, fetcher, accountManager);
     }
 
@@ -91,10 +96,14 @@ public class RSSMessagingService implements MessagingService {
         return accountManager;
     }
 
-    public MessagingAccountTransport getAccountTransport(int accountId, Session session) throws MessagingException {
+    public MessagingAccountTransport getAccountTransport(final int accountId, final Session session) {
         return new RSSFeedOperations(accountId, session, fetcher, accountManager);
     }
 
+    public Set<String> getSecretProperties() {
+        return Collections.emptySet();
+    }
+
     public String getDisplayName() {
         return DISPLAY_NAME;
     }
@@ -111,8 +120,19 @@ public class RSSMessagingService implements MessagingService {
         return Collections.emptyList();
     }
 
-    public static String buildFolderId(int accountId, String folder) {
-        StringBuilder stringBuilder = new StringBuilder(ID);
+    public static int[] getStaticRootPerms() {
+        return new int[] {MessagingPermission.READ_FOLDER,
+            MessagingPermission.READ_ALL_OBJECTS,
+            MessagingPermission.NO_PERMISSIONS,
+            MessagingPermission.DELETE_OWN_OBJECTS};
+    }
+
+    public int[] getStaticRootPermissions() {
+        return getStaticRootPerms();
+    }
+
+    public static String buildFolderId(final int accountId, final String folder) {
+        final StringBuilder stringBuilder = new StringBuilder(ID);
         stringBuilder.append("://").append(accountId).append('/').append(folder);
         return stringBuilder.toString();
     }
