@@ -96,7 +96,7 @@ public class SyndMessage implements MessagingMessage {
     private final String sessionId;
     private boolean b_picUrl;
     private String picUrl;
-    private final String id;
+    private String id;
 
     public SyndMessage(final SyndFeed feed, final SyndEntry syndEntry, final String folder, final Session session) throws MessagingException {
         entry = syndEntry;
@@ -148,25 +148,24 @@ public class SyndMessage implements MessagingMessage {
         }
 
         if( isHTML(type) ) {
+            final String textVersion = Utility.textFormat(content.getValue());
+
             final MimeMultipartContent multipart = new MimeMultipartContent();
-            // Text plain
-            {
-                final MimeMessagingBodyPart textPart = new MimeMessagingBodyPart();
-                textPart.setContent(new StringContent(Utility.textFormat(content.getValue())), "text/plain");
-                multipart.addBodyPart(textPart);
-            }
-            // HTML
-            {
-                final MimeMessagingBodyPart htmlPart = new MimeMessagingBodyPart();
-                final HTMLService htmlService = HTMLServiceProvider.getInstance().getHTMLService();
-                if (null == htmlService) {
-                    htmlPart.setContent(new StringContent(content.getValue()), type);
-                } else {
-                    htmlPart.setContent(new StringContent(htmlService.replaceImages(htmlService.sanitize(content.getValue(), null, false, null), sessionId)), type);
-                }
-                multipart.addBodyPart(htmlPart);
+            final MimeMessagingBodyPart textPart = new MimeMessagingBodyPart();
+            textPart.setContent(new StringContent(textVersion), "text/plain");
+
+            multipart.addBodyPart(textPart);
+
+            final MimeMessagingBodyPart htmlPart = new MimeMessagingBodyPart();
+            final HTMLService htmlService = HTMLServiceProvider.getInstance().getHTMLService();
+            if (null == htmlService) {
+                htmlPart.setContent(new StringContent(content.getValue()), type);
+            } else {
+                htmlPart.setContent(new StringContent(htmlService.replaceImages(content.getValue(), sessionId)), type);
             }
 
+            multipart.addBodyPart(htmlPart);
+
             final MimeContentType contentType = new MimeContentType("multipart/alternative");
             addHeader(KnownHeader.CONTENT_TYPE, contentType);
 
